==> Weblate-2.4.tar.bz2: Weblate-2.4/weblate/trans/tests/test_sitemaps.py <==
# -*- coding: utf-8 -*-
#
# Copyright © 2012 - 2015 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <http://weblate.org/>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Tests for sitemaps.
"""

from weblate.trans.tests.test_views import ViewTestCase
from xml.etree import cElementTree as ElementTree


class SitemapTest(ViewTestCase):
    def test_sitemaps(self):
        # Get root sitemap
        response = self.client.get('/sitemap.xml')
        self.assertContains(response, '<sitemapindex')

        # Parse it
        tree = ElementTree.fromstring(response.content)
        sitemaps = tree.findall(
            '{http://www.sitemaps.org/schemas/sitemap/0.9}sitemap'
        )
        for sitemap in sitemaps:
            location = sitemap.find(
                '{http://www.sitemaps.org/schemas/sitemap/0.9}loc'
            )
            response = self.client.get(location.text)
            self.assertContains(response, '<urlset')
            # Try if it's a valid XML
            ElementTree.fromstring(response.content)

==> Weblate-3.8.tar.bz2: Weblate-3.8/weblate/trans/tests/test_sitemaps.py <==
# -*- coding: utf-8 -*-
#
# Copyright © 2012 - 2019 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

"""
Tests for sitemaps.
"""

from xml.etree import ElementTree

from weblate.trans.tests.test_views import FixtureTestCase


class SitemapTest(FixtureTestCase):
    def test_sitemaps(self):
        # Get root sitemap
        response = self.client.get('/sitemap.xml')
        self.assertContains(response, '<sitemapindex')

        # Parse it
        tree = ElementTree.fromstring(response.content)
        sitemaps = tree.findall(
            '{http://www.sitemaps.org/schemas/sitemap/0.9}sitemap'
        )
        for sitemap in sitemaps:
            location = sitemap.find(
                '{http://www.sitemaps.org/schemas/sitemap/0.9}loc'
            )
            response = self.client.get(location.text)
            self.assertContains(response, '<urlset')
            # Try if it's a valid XML
            ElementTree.fromstring(response.content)
